@@ -5,10 +5,15 @@ from parchmint.component import Component
 from parchmint.connection import Connection
 from parchmint.params import Params
 from parchmint.layer import Layer
+import jsonschema
+import pathlib
+import parchmint
+import json
+
+PROJECT_DIR = pathlib.Path(parchmint.__file__).parent.parent.absolute()
 
 
 class Device:
-
     def __init__(self, json=None):
         self.name: str = ""
         self.components: List[Component] = []
@@ -18,13 +23,13 @@ class Device:
         self.features = []  # Store Raw JSON Objects for now
         self.xspan: Optional[int] = None
         self.yspan: Optional[int] = None
-        self.G = nx.MultiGraph()
+        self.G = nx.MultiDiGraph()
 
         if json:
             self.parse_from_json(json)
             self.generate_network()
 
-    def add_component(self, component):
+    def add_component(self, component: Component):
         if isinstance(component, Component):
             # Check if Component Exists, if it does ignore it
             if self.does_component_exist(component):
@@ -33,15 +38,35 @@ class Device:
                     "hence skipping the component".format(component.name)
                 )
             self.components.append(component)
+        else:
+            raise Exception(
+                "Could not add component since its not an instance of parchmint:Component"
+            )
 
-    def add_connection(self, connection):
+    def add_connection(self, connection: Connection):
         if isinstance(connection, Connection):
             self.connections.append(connection)
+        else:
+            raise Exception(
+                "Could not add component since its not an instance of parchmint:Connection"
+            )
 
     def add_layer(self, layer):
         if isinstance(layer, Layer):
             self.layers.append(layer)
 
+    def merge_netlist(self, netlist):
+        # TODO - Figure out how to merge the layers later
+        for layer in netlist.layers:
+            if layer not in self.layers:
+                self.add_layer(layer)
+
+        for component in netlist.components:
+            self.add_component(component)
+
+        for connection in netlist.connections:
+            self.add_connection(connection)
+
     def parse_from_json(self, json):
         self.name = json["name"]
 
@@ -59,11 +84,15 @@ class Device:
                 self.xspan = self.params.get_param("xspan")
             elif self.params.exists("width"):
                 self.xspan = self.params.get_param("width")
+            elif self.params.exists("x-span"):
+                self.xspan = self.params.get_param("x-span")
 
             if self.params.exists("yspan"):
                 self.yspan = self.params.get_param("yspan")
             elif self.params.exists("length"):
                 self.yspan = self.params.get_param("length")
+            elif self.params.exists("y-span"):
+                self.yspan = self.params.get_param("y-span")
 
         for layer in json["layers"]:
             self.add_layer(Layer(layer))
@@ -143,3 +172,16 @@ class Device:
             "layers": [layer.to_parchmint_v1() for layer in self.layers],
         }
 
+    @staticmethod
+    def validate_V1(json_str: str) -> None:
+        schema_path = PROJECT_DIR.joinpath("schemas").joinpath("V1.json")
+        with open(schema_path) as json_file:
+            schema = json.load(json_file)
+            json_data = json.loads(json_str)
+            validator = jsonschema.Draft7Validator(schema)
+
+            errors = validator.iter_errors(json_data)  # get all validation errors
+
+            for error in errors:
+                print(error)
+                print("------")
